from django.conf import settings

DEFAULTS = {
    'POLICY_REVERSE_ID': 'privacy-policy',  # url reverse name or reverse page id if used together with CMS
    'WITH_ANALYSIS_CHOICE': True,
}


class Settings:
    def __init__(self, site_settings=None, defaults=None):
        self.site_settings = site_settings
        self.defaults = defaults

    def __getattr__(self, attr):
        if attr not in self.defaults:
            raise AttributeError("Invalid setting key: '%s'" % attr)
        return self.site_settings.get(attr, self.defaults[attr])

    def get_all(self):
        return [(k, getattr(self, k)) for k in self.defaults.keys()]


cookie_alert_settings = Settings(getattr(settings, 'COOKIE_ALERT', {}), DEFAULTS)



import os
import sys

BASE_DIR = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

# the name of the whole site
SITE_NAME = "cookie_alert"
ROOT_URLCONF = 'cookie_alert.test_urls'

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'abc'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True
SITE_ID = 1

LANGUAGES = (
    ('en-us', 'English'),
)

CMS_TEMPLATES = [
    ('home.html', 'Home page template'),
]

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'dev/db.sqlite3',
        'TEST_NAME': ':memory:',
    }
}

ALLOWED_HOSTS = ['*']

# Application definition

INSTALLED_APPS = [
    'djangocms_admin_style',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites',

    'cms',
    'menus',
    'treebeard',
    'sekizai',
    'easy_thumbnails',
    'cmsplus',

    'cookie_alert',
    'cookie_alert.tests',
]


MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'cms.middleware.user.CurrentUserMiddleware',
    'cms.middleware.page.CurrentPageMiddleware',
    'cms.middleware.toolbar.ToolbarMiddleware',
    'cms.middleware.language.LanguageCookieMiddleware',
    'cms.middleware.utils.ApphookReloadMiddleware',
]

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'cms_cookie_alert/templates')]
        ,
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'cms.context_processors.cms_settings',
                'sekizai.context_processors.sekizai',
                'django.template.context_processors.i18n',
            ],
        },
    },
]


AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator'},
    {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator'},
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator'},
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator'},
]

STATIC_URL = '/static/'
MEDIA_URL = '/m/'

MEDIA_ROOT = 'media/'



from django import template
from django.template.defaultfilters import register
from django.template.loader import render_to_string

from cookie_alert.app_settings import cookie_alert_settings


class CookieAlertNode(template.Node):

    def __init__(self, template_name):
        if not template_name:
            self.template_name = 'cookie_alert/footer.html'
        else:
            self.template_name = template.Variable(template_name)

    def render(self, context):
        request = context['request']
        if 'cookies_confirmed' in request.COOKIES:
            return ''  # do nothing

        try:
            self.template_name = self.template_name.resolve(context)
        except Exception:
            pass

        template_context = {
            'with_analysis_choice': cookie_alert_settings.WITH_ANALYSIS_CHOICE,
        }
        return render_to_string(template_name=self.template_name,
                                context=template_context, request=request)


@register.tag(name='render_cookie_alert')
def do_render_cookie_alert(parser, token):
    try:
        # split_contents() knows not to split quoted strings.
        tag_name, template_name = token.split_contents()
    except ValueError:
        template_name = None

    return CookieAlertNode(template_name=template_name)



from cms import api
from django.http import SimpleCookie
from django.test import TestCase


class CookieTest(TestCase):
    def setUp(self) -> None:
        self.client.cookies = SimpleCookie({
            'cookies_confirmed': True,
            'analysis_confirmed': True,
        })
        self.page = api.create_page(
            'Test',
            'home.html',
            'en-us',
            slug='home',
        )
        self.page.publish('en-us')

    def test_set_cookies(self):
        self.assertTrue(self.page.is_published('en-us'), "Could not publish page")
        response = self.client.get('/home', follow=True)
        html = response.content.decode('utf-8')
        self.assertTrue('id="cookie-alert"' not in html, "Cookie alert still showed after confirmation")



import sys
from cookie_alert import __version__
from setuptools import setup
from setuptools.command.test import test as TestCommand


class Tox(TestCommand):

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.tox_args = None

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import tox
        import shlex
        args = self.tox_args
        if args:
            args = shlex.split(self.tox_args)
        errno = tox.cmdline(args=args)
        sys.exit(errno)


TESTS_REQUIRE = ['tox >= 2.3']


setup(
    name='django-cookie-alert',
    version=__version__,
    author='InQuant GmbH',
    author_email='info@inquant.de',
    packages=['cookie_alert'],
    url='https://github.com/InQuant/cookie_alert',
    license='MIT',
    description='Basic template tag to add cookie consent functionality with various templates.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    zip_safe=False,
    include_package_data=True,
    package_data={'': ['README.md'], },
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    tests_require=TESTS_REQUIRE,
    extras_require={
        'test': TESTS_REQUIRE,
    },
    cmdclass={'test': Tox}
)